==> hivemind_0.4.3.orig.tar.gz: hivemind-0.4.3/hivemind/resource.py <==
# -*- coding: utf-8 -*-
# HiveMind - Distributed mind map editor for Maemo 5 platform
# Copyright (C) 2010-2011 HiveMind developers
#
# HiveMind is the legal property of its developers, whose names are
# noticed in  or  annotations at the beginning of each
# module or class.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA

'''
Application resource manager

@author: Alexander Kulikov 
'''

import os
import hivemind.settings as settings
import hivemind.sysconfig as sysconfig
from PyQt4.QtGui import QIcon, QImage, QPixmap, QPixmapCache
from PyQt4.QtSvg import QSvgRenderer

__ICONS = {}
'''Hash table containing icons'''

__SVG_ICONS = {}
'''Hash table containing svg icons'''

def getIconByName(name):
    '''
    Get the image with the given name.
    If the name is not present, supply None instead

    @rtype: QImage
    '''
    if __ICONS.has_key(name):
        return __ICONS[name]
    return None

def getSvgIconByName(name):
    '''
    Get the svg image with the given name.
    If the name is not present, supply None instead

    @rtype: QImage
    '''
    if __SVG_ICONS.has_key(name):
        return __SVG_ICONS[name]
    return None

def getImage(name):
    '''
    @param name: name of image file without extension

    @return: new image object on first call, cached image afterwards 
    @rtype: QPixmap
    '''
    return _getImage(name, '.png')

def getScalableImage(name):
    '''
    @param name: name of image file without extension

    @return: new image object on first call, cached image afterwards
    @rtype: QPixmap
    '''
    return _getImage(name, '.svg')

def _getImage(name, extension):
    '''
    @param name: name of image file without extension
    @param extension: image file extension

    @return: new image object on first call, cached image afterwards
    @rtype: QPixmap
    '''
    fullname = os.path.join(sysconfig.BASEDIR, 'images', name + extension)
    image = QPixmap()
    if not QPixmapCache.find(fullname, image):
        image = QPixmap(fullname)
        QPixmapCache.insert(fullname, image)
    return image

__NORMAL_STATE_IMAGE_SUFFIX = '_normal'
'''Suffix for image to be displayed in normal mode'''

__SELECTED_STATE_IMAGE_SUFFIX = '_selected'
'''Suffix for image to be displayed in selected mode'''

__DISABLED_STATE_IMAGE_SUFFIX = '_disabled'
'''Suffix for imagee to be displayed in disabled mode'''

def getIcon(name):
    '''
    @param name: base name of the pictures representig icon
    @type name: str
    
    @return: new icon containg normal, selected and disabled states image
    @rtype: QIcon
    '''
    icon = QIcon()
    icon.addPixmap(getImage(name + __NORMAL_STATE_IMAGE_SUFFIX), QIcon.Normal, QIcon.Off)
    icon.addPixmap(getImage(name + __SELECTED_STATE_IMAGE_SUFFIX), QIcon.Selected, QIcon.Off)
    icon.addPixmap(getImage(name + __DISABLED_STATE_IMAGE_SUFFIX), QIcon.Disabled, QIcon.Off)
    return icon

def _loadIcons():
    '''
    Load icons to the hash table using a list of
    names of icons from the configuration file
    '''
    path = os.path.join(sysconfig.BASEDIR, 'mapicons')
    for name in settings.get("listIcons"):
        fullPath = os.path.join(path, name + '.png')
        image = QImage(fullPath)
        if image:
            __ICONS[name] = image
    for name in settings.get("listSvgIcons"):
        fullPath = os.path.join(path, name + '.svg')
        image = QSvgRenderer(fullPath)
        if image:
            __SVG_ICONS[name] = image

# Initialization
_loadIcons()

==> hivemind_0.4.6.orig.tar.gz: hivemind-0.4.6/hivemind/resource.py <==
# -*- coding: utf-8 -*-
# HiveMind - Distributed mind map editor for Maemo 5 platform
# Copyright (C) 2010-2011 HiveMind developers
#
# HiveMind is the legal property of its developers, whose names are
# noticed in  or  annotations at the beginning of each
# module or class.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA

'''
Application resource manager

@author: Alexander Kulikov 
'''

import os
import hivemind.settings as settings
import hivemind.sysconfig as sysconfig
from PyQt4.QtGui import QIcon, QImage, QPixmap, QPixmapCache
from PyQt4.QtSvg import QSvgRenderer

__ICONS = {}
'''Hash table containing icons'''

__SVG_ICONS = {}
'''Hash table containing svg icons'''

def getIconByName(name):
    '''
    Get the image with the given name.
    If the name is not present, supply None instead

    @rtype: QImage
    '''
    if __ICONS.has_key(name):
        return __ICONS[name]
    return None

def getSvgIconByName(name):
    '''
    Get the svg image with the given name.
    If the name is not present, supply None instead

    @rtype: QImage
    '''
    if __SVG_ICONS.has_key(name):
        return __SVG_ICONS[name]
    return None

def getImage(name):
    '''
    @param name: name of image file without extension

    @return: new image object on first call, cached image afterwards 
    @rtype: QPixmap
    '''
    return _getImage(name, '.png')

def getScalableImage(name):
    '''
    @param name: name of image file without extension

    @return: new image object on first call, cached image afterwards
    @rtype: QPixmap
    '''
    return _getImage(name, '.svg')

def _getImage(name, extension):
    '''
    @param name: name of image file without extension
    @param extension: image file extension

    @return: new image object on first call, cached image afterwards
    @rtype: QPixmap
    '''
    fullname = os.path.join(sysconfig.BASEDIR, 'images', name + extension)
    image = QPixmap()
    if not QPixmapCache.find(fullname, image):
        image = QPixmap(fullname)
        QPixmapCache.insert(fullname, image)
    return image

__NORMAL_STATE_IMAGE_SUFFIX = '_normal'
'''Suffix for image to be displayed in normal mode'''

__SELECTED_STATE_IMAGE_SUFFIX = '_selected'
'''Suffix for image to be displayed in selected mode'''

__DISABLED_STATE_IMAGE_SUFFIX = '_disabled'
'''Suffix for imagee to be displayed in disabled mode'''

def getIcon(name):
    '''
    @param name: base name of the pictures representig icon
    @type name: str
    
    @return: new icon containg normal, selected and disabled states image
    @rtype: QIcon
    '''
    icon = QIcon()
    icon.addPixmap(getImage(name + __NORMAL_STATE_IMAGE_SUFFIX), QIcon.Normal, QIcon.Off)
    icon.addPixmap(getImage(name + __SELECTED_STATE_IMAGE_SUFFIX), QIcon.Selected, QIcon.Off)
    icon.addPixmap(getImage(name + __DISABLED_STATE_IMAGE_SUFFIX), QIcon.Disabled, QIcon.Off)
    return icon

def _initializeIcons():
    '''
    Load icons to the hash table using a list of
    names of icons from the configuration file
    '''
    path = os.path.join(sysconfig.BASEDIR, 'mapicons')
    for name in settings.get("listIcons"):
        fullPath = os.path.join(path, name + '.png')
        image = QImage(fullPath)
        if image:
            __ICONS[name] = image
    for name in settings.get("listSvgIcons"):
        fullPath = os.path.join(path, name + '.svg')
        image = QSvgRenderer(fullPath)
        if image:
            __SVG_ICONS[name] = image
    # icons for windows
    if os.name == 'nt':
        iconpaths = QIcon.themeSearchPaths()
        iconpaths.append(os.path.join(sysconfig.BASEDIR, 'winicons'))
        QIcon.setThemeSearchPaths(iconpaths)
        QIcon.setThemeName('wintheme')

# Initialization
_initializeIcons()
